@@ -1,85 +1,65 @@
 <?xml version="1.0" encoding="utf-8"?>
 <!DOCTYPE TS>
-<TS version="2.1" language="de_DE">
+<TS version="2.1" language="de">
 <context>
     <name>MXDateTime</name>
     <message>
         <location filename="../datetime.ui" line="20"/>
         <location filename="../datetime.cpp" line="596"/>
         <source>MX Date &amp; Time</source>
-        <translation type="unfinished"></translation>
+        <translation>MX Datum &amp; Zeit</translation>
     </message>
     <message>
         <location filename="../datetime.ui" line="26"/>
         <source>Close</source>
-        <translation type="unfinished"></translation>
+        <translation>Schließen</translation>
     </message>
     <message>
         <location filename="../datetime.ui" line="40"/>
         <source>Help</source>
-        <translation type="unfinished"></translation>
+        <translation>Hilfe</translation>
     </message>
     <message>
         <location filename="../datetime.ui" line="73"/>
         <source>Apply</source>
-        <translation type="unfinished"></translation>
+        <translation>Anwenden</translation>
     </message>
     <message>
         <location filename="../datetime.ui" line="100"/>
         <source>About...</source>
-        <translation type="unfinished"></translation>
+        <translation>Über...</translation>
     </message>
     <message>
         <location filename="../datetime.ui" line="124"/>
         <source>Date &amp;&amp; Time</source>
-        <translation type="unfinished"></translation>
+        <translation>Datum &amp;&amp; Zeit</translation>
     </message>
     <message>
         <location filename="../datetime.ui" line="192"/>
         <source>H:mm:ss</source>
-        <translation type="unfinished"></translation>
+        <translation>H:mm:ss</translation>
     </message>
     <message>
         <location filename="../datetime.ui" line="278"/>
         <location filename="../datetime.cpp" line="296"/>
         <location filename="../datetime.cpp" line="303"/>
         <source>Hardware Clock</source>
-        <translation type="unfinished"></translation>
+        <translation>Hardware Uhr</translation>
     </message>
     <message>
         <location filename="../datetime.ui" line="284"/>
         <source>Hardware Clock tools</source>
-        <translation type="unfinished"></translation>
+        <translation>Hardware Uhr Tools</translation>
     </message>
     <message>
         <location filename="../datetime.ui" line="290"/>
         <source>Obtain information from the Hardware Clock and present it in the box below.</source>
-        <translation type="unfinished"></translation>
+        <translation>Hole Informationen von der Hardware Uhr und zeige sie in der Box Unten.</translation>
     </message>
     <message>
         <location filename="../datetime.ui" line="293"/>
         <source>Read the Hardware Clock</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <location filename="../datetime.ui" line="329"/>
-        <source>Time transfer</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <location filename="../datetime.ui" line="348"/>
-        <source>Immediately set the Hardware Clock to match the current time registered by the System Clock.</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <location filename="../datetime.ui" line="351"/>
-        <source>System Clock to Hardware Clock</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <location filename="../datetime.ui" line="335"/>
-        <source>Immediately set the System Clock to match the current time registered by the Hardware Clock.</source>
-        <translation type="unfinished"></translation>
+        <translation>Hardware Uhr auslesen</translation>
     </message>
     <message>
         <location filename="../datetime.ui" line="303"/>
@@ -91,10 +71,30 @@
         <source>Drift Adjust</source>
         <translation type="unfinished"></translation>
     </message>
+    <message>
+        <location filename="../datetime.ui" line="329"/>
+        <source>Time transfer</source>
+        <translation>Zeit übertragen</translation>
+    </message>
+    <message>
+        <location filename="../datetime.ui" line="335"/>
+        <source>Immediately set the System Clock to match the current time registered by the Hardware Clock.</source>
+        <translation>Jetzt die Systemzeit auf Hardware Uhrzeit setzen.</translation>
+    </message>
     <message>
         <location filename="../datetime.ui" line="338"/>
         <source>Hardware Clock to System Clock</source>
-        <translation type="unfinished"></translation>
+        <translation>Hardware Zeit nach Systemzeit</translation>
+    </message>
+    <message>
+        <location filename="../datetime.ui" line="348"/>
+        <source>Immediately set the Hardware Clock to match the current time registered by the System Clock.</source>
+        <translation>Jetzt die Hardware Uhr auf Systemzeit setzen.</translation>
+    </message>
+    <message>
+        <location filename="../datetime.ui" line="351"/>
+        <source>System Clock to Hardware Clock</source>
+        <translation>Systemzeit nach Hardware Zeit</translation>
     </message>
     <message>
         <location filename="../datetime.ui" line="361"/>
@@ -109,92 +109,92 @@
     <message>
         <location filename="../datetime.ui" line="374"/>
         <source>Time zone for the Hardware Clock</source>
-        <translation type="unfinished"></translation>
+        <translation>Zeitzone für die Hardware Uhr</translation>
     </message>
     <message>
         <location filename="../datetime.ui" line="380"/>
         <source>Local time</source>
-        <translation type="unfinished"></translation>
+        <translation>Ortszeit</translation>
     </message>
     <message>
         <location filename="../datetime.ui" line="383"/>
         <source>Local</source>
-        <translation type="unfinished"></translation>
+        <translation>Lokal</translation>
     </message>
     <message>
         <location filename="../datetime.ui" line="390"/>
         <source>Universally Coordinated Time (or Greenwich Meridian Time)</source>
-        <translation type="unfinished"></translation>
+        <translation>UTC oder Greenwich Zeit</translation>
     </message>
     <message>
         <location filename="../datetime.ui" line="393"/>
         <source>UTC</source>
-        <translation type="unfinished"></translation>
+        <translation>UTC</translation>
     </message>
     <message>
         <location filename="../datetime.ui" line="433"/>
         <source>Network Time</source>
-        <translation type="unfinished"></translation>
+        <translation>Netzwerk Zeit</translation>
     </message>
     <message>
         <location filename="../datetime.ui" line="439"/>
         <source>Move the selected item down</source>
-        <translation type="unfinished"></translation>
+        <translation>Selektion nach Unten verschieben</translation>
     </message>
     <message>
         <location filename="../datetime.ui" line="450"/>
         <source>Move the selected item up</source>
-        <translation type="unfinished"></translation>
+        <translation>Selektion nach Oben verschieben</translation>
     </message>
     <message>
         <location filename="../datetime.ui" line="461"/>
         <source>Remove the current item from the list</source>
-        <translation type="unfinished"></translation>
+        <translation>Selektion von der Liste entfernen</translation>
     </message>
     <message>
         <location filename="../datetime.ui" line="472"/>
         <source>Add an item to the list</source>
-        <translation type="unfinished"></translation>
+        <translation>Eintrag zur Liste hinzufügen</translation>
     </message>
     <message>
         <location filename="../datetime.ui" line="498"/>
         <source>Automatically update the System Clock with NTP servers:</source>
-        <translation type="unfinished"></translation>
+        <translation>Die Uhrzeit automatisch mit NTP Servern abgleichen</translation>
     </message>
     <message>
         <location filename="../datetime.ui" line="505"/>
         <source>Immediately update the system clock with NTP servers.</source>
-        <translation type="unfinished"></translation>
+        <translation>Die Uhrzeit jetzt mit NTP Servern abgleichen</translation>
     </message>
     <message>
         <location filename="../datetime.ui" line="508"/>
         <source>Update Now</source>
-        <translation type="unfinished"></translation>
+        <translation>Jetzt abgleichen</translation>
     </message>
     <message>
         <location filename="../datetime.ui" line="520"/>
         <source>List of NTP servers to use.</source>
-        <translation type="unfinished"></translation>
+        <translation>Liste der benutzen NTP Server</translation>
     </message>
     <message>
         <location filename="../datetime.ui" line="536"/>
         <source>Type</source>
-        <translation type="unfinished"></translation>
+        <translation>Typ</translation>
     </message>
     <message>
         <location filename="../datetime.ui" line="541"/>
         <source>Address</source>
-        <translation type="unfinished"></translation>
+        <translation>Adresse</translation>
     </message>
     <message>
         <location filename="../datetime.ui" line="546"/>
         <source>Options</source>
-        <translation type="unfinished"></translation>
+        <translation>Einstellungen</translation>
     </message>
     <message>
         <location filename="../datetime.cpp" line="270"/>
         <source>Reading...</source>
-        <translation type="unfinished"></translation>
+        <translation>Lese...</translation>
     </message>
     <message>
         <location filename="../datetime.cpp" line="284"/>
@@ -220,63 +220,63 @@
     <message>
         <location filename="../datetime.cpp" line="350"/>
         <source>Updating...</source>
-        <translation type="unfinished"></translation>
+        <translation>Abgleich...</translation>
     </message>
     <message>
         <location filename="../datetime.cpp" line="360"/>
         <source>The system clock was updated successfully.</source>
-        <translation type="unfinished"></translation>
+        <translation>Die Systemzeit wurde erfolgreich synchronisiert.</translation>
     </message>
     <message>
         <location filename="../datetime.cpp" line="362"/>
         <source>The system clock could not be updated.</source>
-        <translation type="unfinished"></translation>
+        <translation>Die Systemzeit konnte nicht synchronisiert werden.</translation>
     </message>
     <message>
         <location filename="../datetime.cpp" line="364"/>
         <source>None of the NTP servers on the list are currently enabled.</source>
-        <translation type="unfinished"></translation>
+        <translation>Keiner der NTP Server aus der Liste ist aktiviert.</translation>
     </message>
     <message>
         <location filename="../datetime.cpp" line="595"/>
         <source>About MX Date &amp; Time</source>
-        <translation type="unfinished"></translation>
+        <translation>Über MX Datum &amp; Zeit</translation>
     </message>
     <message>
         <location filename="../datetime.cpp" line="596"/>
         <source>Version: </source>
-        <translation type="unfinished"></translation>
+        <translation>Version:</translation>
     </message>
     <message>
         <location filename="../datetime.cpp" line="597"/>
         <source>GUI program for setting the time and date in MX Linux</source>
-        <translation type="unfinished"></translation>
+        <translation>Grafisches Tool zum Einstellen des Datum und der Uhrzeit in MX Linux</translation>
     </message>
     <message>
         <location filename="../datetime.cpp" line="599"/>
         <source>Copyright (c) MX Linux</source>
-        <translation type="unfinished"></translation>
+        <translation>Copyright (c) MX Linux</translation>
     </message>
     <message>
         <location filename="../datetime.cpp" line="600"/>
         <location filename="../datetime.cpp" line="614"/>
         <source>License</source>
-        <translation type="unfinished"></translation>
+        <translation>Lizenz</translation>
     </message>
     <message>
         <location filename="../datetime.cpp" line="601"/>
         <source>Changelog</source>
-        <translation type="unfinished"></translation>
+        <translation>Changelog</translation>
     </message>
     <message>
         <location filename="../datetime.cpp" line="602"/>
         <source>Cancel</source>
-        <translation type="unfinished"></translation>
+        <translation>Abbrechen</translation>
     </message>
     <message>
         <location filename="../datetime.cpp" line="628"/>
         <source>&amp;Close</source>
-        <translation type="unfinished"></translation>
+        <translation>&amp;Close</translation>
     </message>
     <message>
         <location filename="../datetime.cpp" line="646"/>
